@@ -10,6 +10,9 @@ from threadpool_executor_shrink_able.sharp_threadpoolexecutor import ThreadPoolE
 
 class TpsThreadpoolExecutor:
     def __init__(self, tps=0):
+        """
+        :param tps:   指定线程池每秒运行多少次函数，为0这不限制运行次数
+        """
         self.tps = tps
         self.time_interval = 1 / tps if tps != 0 else 0
         self.pool = ThreadPoolExecutorShrinkAble(500)  # 这是使用的智能线程池，所以可以写很大的数字，具体见另一个包的解释。
